<?php
namespace Teknisa\CTB\Controllers;

use Teknisa\Libs\Service\CRUD;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\CTB\Controllers\TeknisaCrud;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\CTB\Services\Ctb90100SpedContabilService;

class Ctb90100SpedContabilController extends TeknisaCrud{

    protected $crudService;
    protected $parameterBag;
    protected $environment;
    protected $ctb90100SpedContabilService;

    public function __construct(CRUD $crudService, ParameterBag $parameterBag, Environment $environment, ctb90100SpedContabilService $ctb90100SpedContabilService)
    {
        $this->crudService  = $crudService;
        $this->parameterBag = $parameterBag;
        $this->environment  = $environment;
        $this->ctb90100SpedContabilService = $ctb90100SpedContabilService;
    }

    public function donwloadArquivo(Request\DataSet $dataset, Response $response){
        try {
            // Dados do Registro
            $arquivo  = $dataset->getDataSet()->getRows();
            
            // Arquivo para Download[Caminho + Nome + Extenção]
            $arquivo = $arquivo[0]['DSARQUIVO'];
            
            // Download Arquivo
            $this->ctb90100SpedContabilService->donwloadArquivo($arquivo);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function exportaECF(Row $row, Response $response){
        try {
            $row = $row->getRow();
            
            $cdempresa    = $row['CDEMPRESA'];
            $dtanoref     = $row['DTANOREF'];
            $idecfretifi  = $row['IDECFRETIFI'];
            $idecftransmi = $row['IDECFTRANSMI'];
            $nrrecibo     = isset($row['NRRECIBO'])?$row['NRRECIBO']:null;
            
            $nrseqarqmag = $this->ctb90100SpedContabilService->exportaECF(
                $cdempresa, $dtanoref, $idecfretifi, $idecftransmi, $nrrecibo
            );
            
            
            $response->addDataSet(new DataSet('arqmagnetico', ['nrseqarqmag' => $nrseqarqmag]));
            
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function exportaSpedContabil(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            // Chama a função de validação.
            $fileName = $this->ctb90100SpedContabilService->exportaSpedContabil($row);

            // Retorna o nome do arquivo exportado.
            $response->addDataset(new DataSet('columnsToReturn', array("fileName" => $fileName)));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    

}